# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkiot.endpoint import endpoint_data

class CreateRulengDistributeJobRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'CreateRulengDistributeJob','iot')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_SourceInstanceId(self):
		return self.get_query_params().get('SourceInstanceId')

	def set_SourceInstanceId(self,SourceInstanceId):
		self.add_query_param('SourceInstanceId',SourceInstanceId)

	def get_ProductKey(self):
		return self.get_query_params().get('ProductKey')

	def set_ProductKey(self,ProductKey):
		self.add_query_param('ProductKey',ProductKey)

	def get_TargetInstanceId(self):
		return self.get_query_params().get('TargetInstanceId')

	def set_TargetInstanceId(self,TargetInstanceId):
		self.add_query_param('TargetInstanceId',TargetInstanceId)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkiot.endpoint import endpoint_data

class CreateOTAStaticUpgradeJobRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'CreateOTAStaticUpgradeJob','iot')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_RetryCount(self):
		return self.get_query_params().get('RetryCount')

	def set_RetryCount(self,RetryCount):
		self.add_query_param('RetryCount',RetryCount)

	def get_TimeoutInMinutes(self):
		return self.get_query_params().get('TimeoutInMinutes')

	def set_TimeoutInMinutes(self,TimeoutInMinutes):
		self.add_query_param('TimeoutInMinutes',TimeoutInMinutes)

	def get_IotInstanceId(self):
		return self.get_query_params().get('IotInstanceId')

	def set_IotInstanceId(self,IotInstanceId):
		self.add_query_param('IotInstanceId',IotInstanceId)

	def get_TargetSelection(self):
		return self.get_query_params().get('TargetSelection')

	def set_TargetSelection(self,TargetSelection):
		self.add_query_param('TargetSelection',TargetSelection)

	def get_ScheduleFinishTime(self):
		return self.get_query_params().get('ScheduleFinishTime')

	def set_ScheduleFinishTime(self,ScheduleFinishTime):
		self.add_query_param('ScheduleFinishTime',ScheduleFinishTime)

	def get_Tags(self):
		return self.get_query_params().get('Tag')

	def set_Tags(self, Tags):
		for depth1 in range(len(Tags)):
			if Tags[depth1].get('Value') is not None:
				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tags[depth1].get('Value'))
			if Tags[depth1].get('Key') is not None:
				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tags[depth1].get('Key'))

	def get_GrayPercent(self):
		return self.get_query_params().get('GrayPercent')

	def set_GrayPercent(self,GrayPercent):
		self.add_query_param('GrayPercent',GrayPercent)

	def get_DnListFileUrl(self):
		return self.get_query_params().get('DnListFileUrl')

	def set_DnListFileUrl(self,DnListFileUrl):
		self.add_query_param('DnListFileUrl',DnListFileUrl)

	def get_FirmwareId(self):
		return self.get_query_params().get('FirmwareId')

	def set_FirmwareId(self,FirmwareId):
		self.add_query_param('FirmwareId',FirmwareId)

	def get_ProductKey(self):
		return self.get_query_params().get('ProductKey')

	def set_ProductKey(self,ProductKey):
		self.add_query_param('ProductKey',ProductKey)

	def get_RetryInterval(self):
		return self.get_query_params().get('RetryInterval')

	def set_RetryInterval(self,RetryInterval):
		self.add_query_param('RetryInterval',RetryInterval)

	def get_SrcVersions(self):
		return self.get_query_params().get('SrcVersion')

	def set_SrcVersions(self, SrcVersions):
		for depth1 in range(len(SrcVersions)):
			if SrcVersions[depth1] is not None:
				self.add_query_param('SrcVersion.' + str(depth1 + 1) , SrcVersions[depth1])

	def get_ScheduleTime(self):
		return self.get_query_params().get('ScheduleTime')

	def set_ScheduleTime(self,ScheduleTime):
		self.add_query_param('ScheduleTime',ScheduleTime)

	def get_OverwriteMode(self):
		return self.get_query_params().get('OverwriteMode')

	def set_OverwriteMode(self,OverwriteMode):
		self.add_query_param('OverwriteMode',OverwriteMode)

	def get_MaximumPerMinute(self):
		return self.get_query_params().get('MaximumPerMinute')

	def set_MaximumPerMinute(self,MaximumPerMinute):
		self.add_query_param('MaximumPerMinute',MaximumPerMinute)

	def get_TargetDeviceNames(self):
		return self.get_query_params().get('TargetDeviceName')

	def set_TargetDeviceNames(self, TargetDeviceNames):
		for depth1 in range(len(TargetDeviceNames)):
			if TargetDeviceNames[depth1] is not None:
				self.add_query_param('TargetDeviceName.' + str(depth1 + 1) , TargetDeviceNames[depth1])


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkiot.endpoint import endpoint_data

class CreateEdgeDriverVersionRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'CreateEdgeDriverVersion','iot')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ConfigCheckRule(self):
		return self.get_query_params().get('ConfigCheckRule')

	def set_ConfigCheckRule(self,ConfigCheckRule):
		self.add_query_param('ConfigCheckRule',ConfigCheckRule)

	def get_Argument(self):
		return self.get_query_params().get('Argument')

	def set_Argument(self,Argument):
		self.add_query_param('Argument',Argument)

	def get_EdgeVersion(self):
		return self.get_query_params().get('EdgeVersion')

	def set_EdgeVersion(self,EdgeVersion):
		self.add_query_param('EdgeVersion',EdgeVersion)

	def get_Description(self):
		return self.get_query_params().get('Description')

	def set_Description(self,Description):
		self.add_query_param('Description',Description)

	def get_DriverId(self):
		return self.get_query_params().get('DriverId')

	def set_DriverId(self,DriverId):
		self.add_query_param('DriverId',DriverId)

	def get_IotInstanceId(self):
		return self.get_query_params().get('IotInstanceId')

	def set_IotInstanceId(self,IotInstanceId):
		self.add_query_param('IotInstanceId',IotInstanceId)

	def get_ContainerConfig(self):
		return self.get_query_params().get('ContainerConfig')

	def set_ContainerConfig(self,ContainerConfig):
		self.add_query_param('ContainerConfig',ContainerConfig)

	def get_DriverVersion(self):
		return self.get_query_params().get('DriverVersion')

	def set_DriverVersion(self,DriverVersion):
		self.add_query_param('DriverVersion',DriverVersion)

	def get_DriverConfig(self):
		return self.get_query_params().get('DriverConfig')

	def set_DriverConfig(self,DriverConfig):
		self.add_query_param('DriverConfig',DriverConfig)

	def get_SourceConfig(self):
		return self.get_query_params().get('SourceConfig')

	def set_SourceConfig(self,SourceConfig):
		self.add_query_param('SourceConfig',SourceConfig)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkiot.endpoint import endpoint_data

class ListAnalyticsDataRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'ListAnalyticsData','iot')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_PageNum(self):
		return self.get_query_params().get('PageNum')

	def set_PageNum(self,PageNum):
		self.add_query_param('PageNum',PageNum)

	def get_IotInstanceId(self):
		return self.get_query_params().get('IotInstanceId')

	def set_IotInstanceId(self,IotInstanceId):
		self.add_query_param('IotInstanceId',IotInstanceId)

	def get_PageSize(self):
		return self.get_query_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_query_param('PageSize',PageSize)

	def get_IsoId(self):
		return self.get_query_params().get('IsoId')

	def set_IsoId(self,IsoId):
		self.add_query_param('IsoId',IsoId)

	def get_ApiPath(self):
		return self.get_query_params().get('ApiPath')

	def set_ApiPath(self,ApiPath):
		self.add_query_param('ApiPath',ApiPath)

	def get_Conditions(self):
		return self.get_query_params().get('Condition')

	def set_Conditions(self, Conditions):
		for depth1 in range(len(Conditions)):
			if Conditions[depth1].get('FieldName') is not None:
				self.add_query_param('Condition.' + str(depth1 + 1) + '.FieldName', Conditions[depth1].get('FieldName'))
			if Conditions[depth1].get('Operate') is not None:
				self.add_query_param('Condition.' + str(depth1 + 1) + '.Operate', Conditions[depth1].get('Operate'))
			if Conditions[depth1].get('BetweenStart') is not None:
				self.add_query_param('Condition.' + str(depth1 + 1) + '.BetweenStart', Conditions[depth1].get('BetweenStart'))
			if Conditions[depth1].get('BetweenEnd') is not None:
				self.add_query_param('Condition.' + str(depth1 + 1) + '.BetweenEnd', Conditions[depth1].get('BetweenEnd'))
			if Conditions[depth1].get('Value') is not None:
				self.add_query_param('Condition.' + str(depth1 + 1) + '.Value', Conditions[depth1].get('Value'))


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkiot.endpoint import endpoint_data

class CreateEdgeInstanceMessageRoutingRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'CreateEdgeInstanceMessageRouting','iot')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_SourceData(self):
		return self.get_query_params().get('SourceData')

	def set_SourceData(self,SourceData):
		self.add_query_param('SourceData',SourceData)

	def get_TargetType(self):
		return self.get_query_params().get('TargetType')

	def set_TargetType(self,TargetType):
		self.add_query_param('TargetType',TargetType)

	def get_IotInstanceId(self):
		return self.get_query_params().get('IotInstanceId')

	def set_IotInstanceId(self,IotInstanceId):
		self.add_query_param('IotInstanceId',IotInstanceId)

	def get_SourceType(self):
		return self.get_query_params().get('SourceType')

	def set_SourceType(self,SourceType):
		self.add_query_param('SourceType',SourceType)

	def get_TopicFilter(self):
		return self.get_query_params().get('TopicFilter')

	def set_TopicFilter(self,TopicFilter):
		self.add_query_param('TopicFilter',TopicFilter)

	def get_InstanceId(self):
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self,InstanceId):
		self.add_query_param('InstanceId',InstanceId)

	def get_TargetData(self):
		return self.get_query_params().get('TargetData')

	def set_TargetData(self,TargetData):
		self.add_query_param('TargetData',TargetData)

	def get_Name(self):
		return self.get_query_params().get('Name')

	def set_Name(self,Name):
		self.add_query_param('Name',Name)

	def get_TargetIotHubQos(self):
		return self.get_query_params().get('TargetIotHubQos')

	def set_TargetIotHubQos(self,TargetIotHubQos):
		self.add_query_param('TargetIotHubQos',TargetIotHubQos)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkiot.endpoint import endpoint_data

class CreateProductRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'CreateProduct','iot')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_NodeType(self):
		return self.get_query_params().get('NodeType')

	def set_NodeType(self,NodeType):
		self.add_query_param('NodeType',NodeType)

	def get_Description(self):
		return self.get_query_params().get('Description')

	def set_Description(self,Description):
		self.add_query_param('Description',Description)

	def get_CategoryKey(self):
		return self.get_query_params().get('CategoryKey')

	def set_CategoryKey(self,CategoryKey):
		self.add_query_param('CategoryKey',CategoryKey)

	def get_JoinPermissionId(self):
		return self.get_query_params().get('JoinPermissionId')

	def set_JoinPermissionId(self,JoinPermissionId):
		self.add_query_param('JoinPermissionId',JoinPermissionId)

	def get_AuthType(self):
		return self.get_query_params().get('AuthType')

	def set_AuthType(self,AuthType):
		self.add_query_param('AuthType',AuthType)

	def get_ResourceGroupId(self):
		return self.get_query_params().get('ResourceGroupId')

	def set_ResourceGroupId(self,ResourceGroupId):
		self.add_query_param('ResourceGroupId',ResourceGroupId)

	def get_ValidateType(self):
		return self.get_query_params().get('ValidateType')

	def set_ValidateType(self,ValidateType):
		self.add_query_param('ValidateType',ValidateType)

	def get_IotInstanceId(self):
		return self.get_query_params().get('IotInstanceId')

	def set_IotInstanceId(self,IotInstanceId):
		self.add_query_param('IotInstanceId',IotInstanceId)

	def get_ProductName(self):
		return self.get_query_params().get('ProductName')

	def set_ProductName(self,ProductName):
		self.add_query_param('ProductName',ProductName)

	def get_AliyunCommodityCode(self):
		return self.get_query_params().get('AliyunCommodityCode')

	def set_AliyunCommodityCode(self,AliyunCommodityCode):
		self.add_query_param('AliyunCommodityCode',AliyunCommodityCode)

	def get_PublishAuto(self):
		return self.get_query_params().get('PublishAuto')

	def set_PublishAuto(self,PublishAuto):
		self.add_query_param('PublishAuto',PublishAuto)

	def get_DataFormat(self):
		return self.get_query_params().get('DataFormat')

	def set_DataFormat(self,DataFormat):
		self.add_query_param('DataFormat',DataFormat)

	def get_Id2(self):
		return self.get_query_params().get('Id2')

	def set_Id2(self,Id2):
		self.add_query_param('Id2',Id2)

	def get_NetType(self):
		return self.get_query_params().get('NetType')

	def set_NetType(self,NetType):
		self.add_query_param('NetType',NetType)

	def get_ProtocolType(self):
		return self.get_query_params().get('ProtocolType')

	def set_ProtocolType(self,ProtocolType):
		self.add_query_param('ProtocolType',ProtocolType)


# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkiot.endpoint import endpoint_data

class CreateDataAPIServiceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Iot', '2018-01-20', 'CreateDataAPIService','iot')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_RequestParams(self):
		return self.get_body_params().get('RequestParam')

	def set_RequestParams(self, RequestParams):
		for depth1 in range(len(RequestParams)):
			if RequestParams[depth1].get('Name') is not None:
				self.add_body_params('RequestParam.' + str(depth1 + 1) + '.Name', RequestParams[depth1].get('Name'))
			if RequestParams[depth1].get('Type') is not None:
				self.add_body_params('RequestParam.' + str(depth1 + 1) + '.Type', RequestParams[depth1].get('Type'))
			if RequestParams[depth1].get('Desc') is not None:
				self.add_body_params('RequestParam.' + str(depth1 + 1) + '.Desc', RequestParams[depth1].get('Desc'))
			if RequestParams[depth1].get('Example') is not None:
				self.add_body_params('RequestParam.' + str(depth1 + 1) + '.Example', RequestParams[depth1].get('Example'))
			if RequestParams[depth1].get('Required') is not None:
				self.add_body_params('RequestParam.' + str(depth1 + 1) + '.Required', RequestParams[depth1].get('Required'))

	def get_IotInstanceId(self):
		return self.get_body_params().get('IotInstanceId')

	def set_IotInstanceId(self,IotInstanceId):
		self.add_body_params('IotInstanceId', IotInstanceId)

	def get_ApiPath(self):
		return self.get_body_params().get('ApiPath')

	def set_ApiPath(self,ApiPath):
		self.add_body_params('ApiPath', ApiPath)

	def get_TemplateSql(self):
		return self.get_body_params().get('TemplateSql')

	def set_TemplateSql(self,TemplateSql):
		self.add_body_params('TemplateSql', TemplateSql)

	def get_ResponseParams(self):
		return self.get_body_params().get('ResponseParam')

	def set_ResponseParams(self, ResponseParams):
		for depth1 in range(len(ResponseParams)):
			if ResponseParams[depth1].get('Name') is not None:
				self.add_body_params('ResponseParam.' + str(depth1 + 1) + '.Name', ResponseParams[depth1].get('Name'))
			if ResponseParams[depth1].get('Type') is not None:
				self.add_body_params('ResponseParam.' + str(depth1 + 1) + '.Type', ResponseParams[depth1].get('Type'))
			if ResponseParams[depth1].get('Desc') is not None:
				self.add_body_params('ResponseParam.' + str(depth1 + 1) + '.Desc', ResponseParams[depth1].get('Desc'))
			if ResponseParams[depth1].get('Example') is not None:
				self.add_body_params('ResponseParam.' + str(depth1 + 1) + '.Example', ResponseParams[depth1].get('Example'))
			if ResponseParams[depth1].get('Required') is not None:
				self.add_body_params('ResponseParam.' + str(depth1 + 1) + '.Required', ResponseParams[depth1].get('Required'))

	def get_OriginSql(self):
		return self.get_body_params().get('OriginSql')

	def set_OriginSql(self,OriginSql):
		self.add_body_params('OriginSql', OriginSql)

	def get_DisplayName(self):
		return self.get_body_params().get('DisplayName')

	def set_DisplayName(self,DisplayName):
		self.add_body_params('DisplayName', DisplayName)

	def get_Desc(self):
		return self.get_body_params().get('Desc')

	def set_Desc(self,Desc):
		self.add_body_params('Desc', Desc)